@@ -515,12 +515,15 @@ AGES: while( !$DONE && @AGES ) {
 
         # Scroll forward
         $start = time;
-        $result = es_request('_search/scroll', {
-            uri_param => {
-                scroll    => $q->scroll,
+        $result = es_request('_search/scroll',
+            {
+                method => 'POST',
             },
-            body => $result->{_scroll_id},
-        });
+            {
+                scroll => $q->scroll,
+                scroll_id => $result->{_scroll_id},
+            }
+        );
         $duration += time - $start;
         last unless $result->{hits} && $result->{hits}{hits} && @{ $result->{hits}{hits} } > 0
     }
@@ -636,7 +639,7 @@ es-search.pl - Provides a CLI for quick searches of data in ElasticSearch daily
 
 =head1 VERSION
 
-version 6.3
+version 6.4
 
 =head1 SYNOPSIS
 
@@ -996,6 +999,26 @@ In the case of --top, this limits the result set to 1,000,000 results.
 The search string is pre-analyzed before being sent to ElasticSearch.  The following plugins
 work to manipulate the query string and provide richer, more complete syntax for CLI applications.
 
+=head2 App::ElasticSearch::Utilities::AutoEscape
+
+Provide an '=' prefix to a query string parameter to promote that parameter to a C<term> filter.
+
+This allows for exact matches of a field without worrying about escaping Lucene special character filters.
+
+E.g.:
+
+    user_agent:"Mozilla/5.0 (iPhone; CPU iPhone OS 12_1_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0 Mobile/15E148 Safari/604.1"
+
+Is evaluated into a weird query that doesn't do what you want.   However:
+
+    =user_agent:"Mozilla/5.0 (iPhone; CPU iPhone OS 12_1_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0 Mobile/15E148 Safari/604.1"
+
+Is translated into:
+
+    { term => { user_agent => "Mozilla/5.0 (iPhone; CPU iPhone OS 12_1_2 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/12.0 Mobile/15E148 Safari/604.1" } }
+
+Which provides an exact match to the term in the query.
+
 =head2 App::ElasticSearch::Utilities::Barewords
 
 The following barewords are transformed:
@@ -1099,6 +1122,12 @@ or:
 This option will iterate through the whole file and unique the elements of the list.  They will then be transformed into
 an appropriate L<terms query|http://www.elasticsearch.org/guide/en/elasticsearch/reference/current/query-dsl-terms-query.html>.
 
+=head2 App::ElasticSearch::Utilities::QueryString::Nested
+
+Implement the proposed nested query syntax early.  Example:
+
+    nested_path:"field:match AND string"
+
 =head1 Meta-Queries
 
 Helpful in building queries is the --bases and --fields options which lists the index bases and fields:
@@ -1115,7 +1144,7 @@ Brad Lhotsky <brad@divisionbyzero.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Brad Lhotsky.
+This software is Copyright (c) 2019 by Brad Lhotsky.
 
 This is free software, licensed under:
 
